@@ -27,12 +27,14 @@ pip install cloudcomponents.cdk-codepipeline-anchore-inline-scan-action
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Pipeline, Artifact } from '@aws-cdk/aws-codepipeline';
-import { CodeCommitSourceAction } from '@aws-cdk/aws-codepipeline-actions';
-import { CodePipelineDockerfileLinterAction } from '@cloudcomponents/cdk-codepipeline-dockerfile-linter-action';
 import { CodePipelineAnchoreInlineScanAction } from '@cloudcomponents/cdk-codepipeline-anchore-inline-scan-action';
+import { CodePipelineDockerfileLinterAction } from '@cloudcomponents/cdk-codepipeline-dockerfile-linter-action';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Pipeline, Artifact } from 'aws-cdk-lib/aws-codepipeline';
+import { CodeCommitSourceAction } from 'aws-cdk-lib/aws-codepipeline-actions';
+import { Construct } from 'constructs';
+
 export class ContainerAuditStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
     super(scope, id, props);
@@ -106,7 +108,7 @@ import aws_cdk.aws_codepipeline
 import aws_cdk.aws_codepipeline_actions
 import aws_cdk.aws_iam
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class CodePipelineAnchoreInlineScanAction(
@@ -164,7 +166,7 @@ class CodePipelineAnchoreInlineScanAction(
     @jsii.member(jsii_name="bound")
     def _bound(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         _stage: aws_cdk.aws_codepipeline.IStage,
         *,
         bucket: aws_cdk.aws_s3.IBucket,
